@@ -1,5 +1,5 @@
 #![cfg_attr(not(any(feature = "std", doc)), no_std)]
-#![cfg_attr(any(feature = "static", doc), feature(once_cell))]
+#![cfg_attr(any(feature = "global", doc), feature(once_cell))]
 #![feature(doc_cfg, generic_associated_types, ptr_metadata, unsize)]
 #![deny(missing_docs)]
 
@@ -11,16 +11,16 @@
 //!
 //! rattish is presently only experimental, and depends on unstable compiler
 //! features including [`generic_associated_types`], [`ptr_metadata`] and
-//! [`unsize`]; [`once_cell`] is used by [`DB`] (enabled by the `static`
+//! [`unsize`]; [`once_cell`] is used by [`DB`] (enabled by the `global`
 //! feature).  Accordingly, a nightly toolchain is required.
 //!
 //! # Example
 //! ```rust
 //! #![feature(generic_associated_types, once_cell)]
-//! # #[cfg(feature = "static")]
+//! # #[cfg(feature = "global")]
 //! # {
 //!
-//! use rattish::{coercible_trait, rtti_static, GlobalDynCast};
+//! use rattish::{coercible_trait, rtti_global, GlobalDynCast};
 //! use std::{any::Any, cell::RefCell, fmt, rc::Rc};
 //!
 //! // Casting from an object of trait Foo requires Foo to have
@@ -48,7 +48,7 @@
 //!     // ..except that Bar must be registered in the database with
 //!     // each implementing (concrete) type that might underlie a
 //!     // dynamic cast to one of its objects
-//!     rtti_static! {
+//!     rtti_global! {
 //!         Bar: Qux,
 //!
 //!         // example of another trait with multiple implementations
@@ -99,7 +99,7 @@ use container::{Coerced, Coercible, InnermostTypeId, Metadata, Pointer};
 use core::ptr;
 use db::{TypeDatabase, TypeDatabaseEntryExt};
 
-#[cfg(any(feature = "static", doc))]
+#[cfg(any(feature = "global", doc))]
 use db::hash_map::DB;
 
 /// A type whose implementations can be dynamically determined.
@@ -122,8 +122,8 @@ where
 /// A type that can be dynamically cast.
 pub trait DynCast<'a, DB>
 where
-    Self: Pointer<'a> + InnermostTypeId,
-    Self::Target: Coercible,
+    Self: Pointer + InnermostTypeId,
+    Self::Inner: Coercible,
     DB: TypeDatabase,
 {
     /// Cast `self`'s ultimate concrete type to `U`, if registered as an
@@ -132,7 +132,7 @@ where
     where
         U: 'static + ?Sized,
         Self::Coerced<U>: Sized,
-        Coerced<Self::Target, U>: ptr::Pointee<Metadata = Metadata<U>>,
+        Coerced<Self::Inner, U>: ptr::Pointee<Metadata = Metadata<U>>,
     {
         match db.get_entry() {
             Some(entry) => entry.cast(self),
@@ -150,14 +150,14 @@ where
 
 impl<'a, DB, P> DynCast<'a, DB> for P
 where
-    Self: Pointer<'a> + InnermostTypeId,
-    Self::Target: Coercible,
+    Self: Pointer + InnermostTypeId,
+    Self::Inner: Coercible,
     DB: TypeDatabase,
 {
 }
 
-#[cfg(any(feature = "static", doc))]
-#[doc(cfg(feature = "static"))]
+#[cfg(any(feature = "global", doc))]
+#[doc(cfg(feature = "global"))]
 /// A type whose implementations can be dynamically determined using the global
 /// [`DB`].
 pub trait GlobalDynImplements<'a>
@@ -174,13 +174,13 @@ where
     }
 }
 
-#[cfg(any(feature = "static", doc))]
-#[doc(cfg(feature = "static"))]
+#[cfg(any(feature = "global", doc))]
+#[doc(cfg(feature = "global"))]
 /// A type that can be dynamically cast using the global [`DB`].
 pub trait GlobalDynCast<'a>
 where
-    Self: Pointer<'a> + InnermostTypeId,
-    Self::Target: Coercible,
+    Self: Pointer + InnermostTypeId,
+    Self::Inner: Coercible,
 {
     /// Cast `self`'s ultimate concrete type to `U`, if registered as an
     /// implementor of `U` in the global [`DB`].
@@ -188,21 +188,21 @@ where
     where
         U: 'static + ?Sized,
         Self::Coerced<U>: Sized,
-        Coerced<Self::Target, U>: ptr::Pointee<Metadata = Metadata<U>>,
+        Coerced<Self::Inner, U>: ptr::Pointee<Metadata = Metadata<U>>,
     {
         DynCast::dyn_cast::<U>(self, DB.get().expect("initialized database"))
     }
 }
 
-#[cfg(any(feature = "static", doc))]
-#[doc(cfg(feature = "static"))]
+#[cfg(any(feature = "global", doc))]
+#[doc(cfg(feature = "global"))]
 impl<'a, P> GlobalDynImplements<'a> for P where Self: InnermostTypeId {}
 
-#[cfg(any(feature = "static", doc))]
-#[doc(cfg(feature = "static"))]
+#[cfg(any(feature = "global", doc))]
+#[doc(cfg(feature = "global"))]
 impl<'a, P> GlobalDynCast<'a> for P
 where
-    Self: Pointer<'a> + InnermostTypeId,
-    Self::Target: Coercible,
+    Self: Pointer + InnermostTypeId,
+    Self::Inner: Coercible,
 {
 }
